@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Macro.h 2084 2006-11-25 17:00:47Z svn $
+ * $Id: Macro.h 2165 2006-12-03 19:06:50Z svn $
  *****************************************************************************/
 
 /**
@@ -174,6 +174,12 @@ using namespace std;
  * @param[in] pointer ポインタ
  */
 #define AS_CHAR(pointer) reinterpret_cast<char *>(pointer)
+/**
+ * ポインタを unsigned char * にキャストするマクロ．
+ *
+ * @param[in] pointer ポインタ
+ */
+#define AS_UCHAR(pointer) reinterpret_cast<unsigned char *>(pointer)
 /**
  * ポインタを char ** にキャストするマクロ．
  *
