@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageEN.h 2147 2006-12-01 17:59:57Z svn $
+ * $Id: MessageEN.h 2168 2006-12-03 20:56:04Z svn $
  *****************************************************************************/
 
 #ifndef MESSAGE_EN_H
@@ -85,6 +85,7 @@
 #define MESSAGE_POST_FILE_NAME_TOO_LONG     "MESSAGE_POST_FILE_NAME_TOO_LONG"
 #define MESSAGE_POST_READ_FAILED            "MESSAGE_POST_READ_FAILED"
 #define MESSAGE_POST_REMOVE_PASS_TOO_LONG   "MESSAGE_POST_REMOVE_PASS_TOO_LONG"
+#define MESSAGE_POST_INTERVAL_TOO_SHORT     "MESSAGE_POST_INTERVAL_TOO_SHORT"
 #define MESSAGE_PROGRAM_TOO_OLD             "MESSAGE_PROGRAM_TOO_OLD"
 #define MESSAGE_RFC1867_CONTENT_SIZE_ZERO   "MESSAGE_RFC1867_CONTENT_SIZE_ZERO"
 #define MESSAGE_RFC1867_CONTENT_TYPE_INVALID "MESSAGE_RFC1867_CONTENT_TYPE_INVALID"
@@ -174,7 +175,7 @@
 // #define MESSAGE_POST_IMAGE_COMMIT_FAILED    "MESSAGE_POST_IMAGE_COMMIT_FAILED"
 // #define MESSAGE_POST_IMAGE_PATH_CREATION_FAILED "MESSAGE_POST_IMAGE_PATH_CREATION_FAILED"
 #define MESSAGE_POST_IMAGE_SIZE_INVALID     "MESSAGE_POST_IMAGE_SIZE_INVALID"
-// #define MESSAGE_POST_INTERVAL_TOO_SHORT     "MESSAGE_POST_INTERVAL_TOO_SHORT"
+
 // #define MESSAGE_POST_MESSAGE_EMPTY          "MESSAGE_POST_MESSAGE_EMPTY"
 // #define MESSAGE_POST_MESSAGE_TOO_LONG       "MESSAGE_POST_MESSAGE_TOO_LONG"
 // #define MESSAGE_POST_NAME_EMPTY             "MESSAGE_POST_NAME_EMPTY"
@@ -202,6 +203,18 @@
 #define MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED "MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED"
 #define MESSAGE_TMPL_WHILE_EXEC_FAILED      "MESSAGE_TMPL_WHILE_EXEC_FAILED"
 
+#define MESSAGE_RFC2822_HEADER_INVALID      "MESSAGE_RFC2822_HEADER_INVALID"
+#define MESSAGE_RFC2822_FORMAT_INVALID      "MESSAGE_RFC2822_FORMAT_INVALID"
+#define MESSAGE_RFC2822_CONTENT_TYPE_INVALID "MESSAGE_RFC2822_CONTENT_TYPE_INVALID"
+
+#define MESSAGE_RFC2822_CONTENT_SIZE_ZERO "MESSAGE_RFC2822_CONTENT_SIZE_ZERO"
+
+#define MESSAGE_RFC2822_ITEM_COUNT_EXCEEDED "MESSAGE_RFC2822_ITEM_COUNT_EXCEEDED"
+#define MESSAGE_RFC2822_TEXT_SIZE_TOO_LARGE "MESSAGE_RFC2822_TEXT_SIZE_TOO_LARGE"
+#define MESSAGE_RFC2822_FILE_SIZE_TOO_LARGE "MESSAGE_RFC2822_FILE_SIZE_TOO_LARGE"
+
+#define MESSAGE_POST_FILE_SIZE_ZERO "MESSAGE_POST_FILE_SIZE_ZERO"
+
 
 #endif
 
