@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploaderConfig.h 2168 2006-12-03 20:56:04Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_CONFIG_H
@@ -115,6 +115,10 @@ public:
 
         return tmpls_[type];
     };
+    bool is_active() const
+    {
+        return is_active_;
+    };
 
     const char *to_string(apr_pool_t *pool);
 
@@ -138,6 +142,8 @@ private:
 
     apr_pool_t *pool_;
 
+    bool is_active_;
+
     apr_shm_t *item_list_shm_;
     apr_shm_t *thumbnail_list_shm_;
     apr_shm_t *item_manager_shm_;
