@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2035 2006-11-23 16:14:21Z svn $
+ * $Id: PostFlowController.cpp 2168 2006-12-03 20:56:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -30,7 +30,7 @@
 #include "PostFlowController.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2035 2006-11-23 16:14:21Z svn $");
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2168 2006-12-03 20:56:04Z svn $");
 
 const apr_size_t PostFlowController::BUSY   = 1;
 const apr_size_t PostFlowController::FREE   = 0;
@@ -202,9 +202,11 @@ void PostFlowController::dump_poster(poster_t *poster)
 #ifdef DEBUG_PostFlowController
 #include "TestRunner.h"
 
+#include "apr_time.h"
+
 const char DUMMY_IP_ADDRESS[]           = "127.0.0.1";
-const apr_time_t MIN_POST_INTERVAL_SEC  = 10;
-const apr_size_t ATTACK_COUNT           = 10000;
+const apr_time_t MIN_POST_INTERVAL_SEC  = 1;
+const apr_size_t ATTACK_COUNT           = 100;
 
 void show_usage(const char *prog_name)
 {
@@ -213,10 +215,21 @@ void show_usage(const char *prog_name)
 
 void run_can_post(PostFlowController *flow_controller)
 {
+    apr_size_t i;
+
     show_test_name("can_post");
 
-    for (apr_size_t i = 0; i < ATTACK_COUNT; i++) {
-        flow_controller->can_post(DUMMY_IP_ADDRESS);
+    flow_controller->regist_post(DUMMY_IP_ADDRESS);
+
+    for (i = 0; i < ATTACK_COUNT; i++) {
+        if (flow_controller->can_post(DUMMY_IP_ADDRESS)) {
+            break;
+        }
+        apr_sleep(100000);
+    }
+
+    if ((i == 0) || (i == ATTACK_COUNT)) {
+        THROW(MESSAGE_BUG_FOUND);
     }
 }
 
