@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploadItemList.cpp 2169 2006-12-04 16:26:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2169 2006-12-04 16:26:56Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -82,6 +82,7 @@ void UploadItemList::add(UploadItem *uitem)
         load_header(uitem, header_list_ + i);
     }
 
+    (*total_file_size_) += uitem->get_file_size();
     (*header_list_size_)++;
 }
 
@@ -105,15 +106,6 @@ void UploadItemList::remove(apr_size_t item_id)
     (*header_list_size_)--;
 }
 
-apr_off_t UploadItemList::get_total_file_size()
-{
-    if (*total_file_size_ == 0) {
-        *total_file_size_ = calc_total_file_size();
-    }
-
-    return *total_file_size_;
-}
-
 UploadItemList *UploadItemList::get_instance(apr_shm_t *shm,
                                              apr_size_t max_list_size)
 {
@@ -205,18 +197,6 @@ apr_size_t UploadItemList::get_index_by_id(apr_size_t item_id) const
     THROW(MESSAGE_LIST_ID_INVALID);
 }
 
-apr_off_t UploadItemList::calc_total_file_size() const
-{
-    apr_off_t total_file_size;
-
-    total_file_size = 0;
-    for (apr_size_t i = 0; i < *header_list_size_; i++) {
-        total_file_size += header_list_[i].file_size;
-    }
-
-    return total_file_size;
-}
-
 void UploadItemList::load_header(UploadItem *uitem,
                                  UploadItem::header_t *header)
 {
