@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploadItemManager.cpp 2169 2006-12-04 16:26:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2169 2006-12-04 16:26:56Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -81,12 +81,13 @@ void UploadItemManager::init(UploadItemList *item_list,
     init_shm();
 }
 
-void UploadItemManager::add(apr_pool_t *pool,
-                            const char *file_name, const char *file_mime,
-                            apr_off_t file_size, const char *file_digest,
-                            const char *file_temp_path,
-                            const char *remove_pass, const char *download_pass,
-                            const char *comment, const char *ip_address)
+apr_size_t UploadItemManager::add(apr_pool_t *pool,
+                                  const char *file_name, const char *file_mime,
+                                  apr_off_t file_size, const char *file_digest,
+                                  const char *file_temp_path,
+                                  const char *remove_pass,
+                                  const char *download_pass,
+                                  const char *comment, const char *ip_address)
 {
     apr_size_t item_id;
     apr_size_t item_index;
@@ -113,14 +114,15 @@ void UploadItemManager::add(apr_pool_t *pool,
         item_list_->remove(old_uitem->get_id());
     }
 
-    item_list_->add(uitem);
     if (item_writer_.write(uitem, file_temp_path)) {
         thumbnail_list_->add(uitem->get_id());
     }
+    item_list_->add(uitem);
 
     *mtime_ = current_time;
-
     sync_all_item(pool);
+
+    return item_id;
 }
 
 void UploadItemManager::remove(apr_pool_t *pool, UploadItem *uitem)
@@ -135,7 +137,6 @@ void UploadItemManager::remove(apr_pool_t *pool, UploadItem *uitem)
     thumbnail_list_->remove(uitem->get_id());
 
     *mtime_ = apr_time_now();
-
     sync_all_item(pool);
 }
 
