@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploaderConfig.cpp 2168 2006-12-03 20:56:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2168 2006-12-03 20:56:04Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -110,16 +110,17 @@ const UploaderConfig::item_t UploaderConfig::ADMIN_VIEW_TEMPLATE = {
  * public メソッド
  *****************************************************************************/
 UploaderConfig::UploaderConfig(apr_pool_t *pool)
-  : base_url(NULL),
-    data_dir_path(NULL),
-    file_dir_path(NULL),
-    temp_dir_path(NULL),
+  : base_url(""),
+    data_dir_path(""),
+    file_dir_path(""),
+    temp_dir_path(""),
     total_file_size_limit(0),
     total_file_number_limit(0),
     file_size_limit(0),
     per_page_item_number(0),
     is_debug_mode(false),
     pool_(pool),
+    is_active_(false),
     item_list_shm_(NULL),
     thumbnail_list_shm_(NULL),
     item_manager_shm_(NULL),
@@ -137,6 +138,10 @@ UploaderConfig::UploaderConfig(apr_pool_t *pool)
 
 void UploaderConfig::init()
 {
+    if (strlen(base_url) == 0) {
+        return;
+    }
+
     check();
     load_template();
 
@@ -162,10 +167,16 @@ void UploaderConfig::init()
 
     flow_controller_ = PostFlowController::get_instance(flow_controller_shm_,
                                                         PST_INTERVAL_SEC);
+
+    is_active_ = true;
 }
 
 void UploaderConfig::child_init()
 {
+    if (!is_active_) {
+        return;
+    }
+
     attach_shm(pool_, item_list_shm_);
     attach_shm(pool_, thumbnail_list_shm_);
     attach_shm(pool_, item_manager_shm_);
@@ -179,6 +190,10 @@ void UploaderConfig::child_init()
 
 void UploaderConfig::finalize()
 {
+    if (!is_active_) {
+        return;
+    }
+
     item_manager_->sync_all_item(pool_);
 
     apr_shm_destroy(flow_controller_shm_);
