@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: uploader_handler.cpp 2170 2006-12-04 17:23:49Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -55,7 +55,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2170 2006-12-04 17:23:49Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -77,10 +77,11 @@ static const char CURRENT_PAGE[]                = "CURRENT_PAGE";
 static const char INDEX_COMMAND[]               = "index";
 static const char THUMBNAIL_COMMAND[]           = "thumbnail";
 static const char THUMBNAIL_VIEW_COMMAND[]      = "view";
-static const char UPLOAD_COMMAND[]              = "upload";
+static const char MAIL_COMMAND[]                = "mail";
 static const char DOWNLOAD_COMMAND[]            = "download";
 static const char REMOVE_COMMAND[]              = "remove";
 static const char RSS_COMMAND[]                 = "rss";
+static const char UPLOAD_COMMAND[]              = "upload";
 static const char ADMIN_COMMAND[]               = "admin";
 
 #ifdef DEBUG
@@ -152,6 +153,18 @@ static int error_with_log(typename Response::Handle *r,
     return error<Response>(r, o, config, message);
 }
 
+template<class Response>
+static int error_with_log(typename Response::Handle *r,
+                          UploaderConfig *config, const char *message)
+{
+    typename Response::Writer o(r);
+
+    logger.info(__FILE__, __LINE__, r, "ERROR: %s (%s)",
+                message, get_last_error_message(r->pool));
+
+    return error<Response>(r, o, config, message);
+}
+
 template<class Response>
 static int index(typename Response::Handle *r, UploaderConfig *config,
                  const char *arg)
@@ -173,9 +186,8 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
         return OK;
     }
 
-    page_count = (config->get_item_list()->size() == 0)
-        ? 1
-        : (config->get_item_list()->size()-1)/config->per_page_item_number + 1;
+    get_page_count(config->get_item_list()->size(),
+                   config->per_page_item_number, &page_count);
     get_page(r->pool, arg, page_count, &page_no);
 
     typename Response::Writer o(r);
@@ -251,7 +263,6 @@ static int thumbnail_view(typename Response::Handle *r, UploaderConfig *config,
             return OK;
         }
 
-
         thumb_file_path = UploadItemIO::get_thumb_path(r->pool,
                                                        config->thumb_dir_path,
                                                        item_id);
@@ -299,9 +310,8 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
         return thumbnail_view<Response>(r, config, thumbnail_arg);
     }
 
-    page_count = (config->get_item_list()->size() == 0)
-        ? 1
-        : (config->get_thumbnail_list()->size()-1)/PER_PAGE_THUMBNAIL_NUMBER + 1;
+    get_page_count(config->get_thumbnail_list()->size(),
+                   PER_PAGE_THUMBNAIL_NUMBER, &page_count);
     get_page(r->pool, arg, page_count, &page_no);
 
     typename Response::Writer o(r);
@@ -345,12 +355,48 @@ static int thumbnail(typename Response::Handle *r, UploaderConfig *config,
     return OK;
 }
 
+template<class Response>
+static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
+                       const char *file_name, const char *file_mime,
+                       apr_off_t file_size, const char *file_digest,
+                       const char *file_temp_path, const char *remove_pass,
+                       const char *download_pass, const char *comment)
+{
+    apr_size_t item_id;
+
+    typename Response::Writer o(r);
+
+    item_id = config->get_item_manager()->add
+        (r->pool, file_name, file_mime, file_size, file_digest,
+         file_temp_path, remove_pass, download_pass, comment,
+         Response::get_remote_ip(r));
+
+    regist_post(config, Response::get_remote_ip(r));
+
+    Response::set_env(r, "uploader_upload", "");
+    Response::set_env(r, "uploader_item_id", apr_itoa(r->pool, item_id));
+
+    return redirect<Response>
+        (r, o, apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR, NULL));
+}
+
 template<class Response>
 static int upload(typename Response::Handle *r, UploaderConfig *config,
                   const char *arg)
 {
     int status;
+
+    const char *file_name;
+    const char *file_mime;
+    apr_off_t file_size;
+    const char *file_digest;
     const char *file_temp_path;
+    const char *remove_pass;
+    const char *download_pass;
+    const char *comment;
+
+    RequestReader::progress_t progress;
+    apr_array_header_t *content_array;
 
     if (!Response::is_post_method(r)) {
         return HTTP_BAD_REQUEST;
@@ -360,51 +406,90 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
         return status;
     }
 
-    typename Response::Writer o(r);
+    if (!can_post(config, Response::get_remote_ip(r))) {
+        return error<Response>(r, config, MESSAGE_POST_INTERVAL_TOO_SHORT);
+    }
+
+    typename Response::Reader i(&progress, r);
+    RFC1867Parser<typename Response::Reader> parser
+        (r->pool, i, config->temp_dir_path,
+         ITM_MAX_COMMENT_SIZE, config->file_size_limit,
+         PST_MAX_ITEM_COUNT);
+
+    content_array = parser.parse(Response::get_content_type(r),
+                                 Response::get_content_size(r));
+
     file_temp_path = NULL;
     try {
-        const char *file_name;
-        const char *file_mime;
-        apr_off_t file_size;
-        const char *file_digest;
-        const char *file_temp_path;
-        const char *remove_pass;
-        const char *download_pass;
-        const char *comment;
-        RequestReader::progress_t progress;
-        apr_array_header_t *content_array;
-
-        typename Response::Reader i(&progress, r);
-        RFC1867Parser<typename Response::Reader> parser
-            (r->pool, i, config->temp_dir_path,
-             ITM_MAX_COMMENT_SIZE, config->file_size_limit,
-             PST_MAX_ITEM_COUNT);
-
-        content_array = parser.parse(Response::get_content_type(r),
-                                     Response::get_content_size(r));
-
         get_upload_param<typename Response::Reader>
             (r->pool, content_array,
              &file_name, &file_mime, &file_size, &file_digest, &file_temp_path,
              &remove_pass, &download_pass, &comment);
 
-        config->get_item_manager()->add
-            (r->pool, file_name, file_mime, file_size, file_digest,
-             file_temp_path, remove_pass, download_pass, comment,
-             Response::get_remote_ip(r));
-
-        regist_post(config, Response::get_remote_ip(r));
-
-        return redirect<Response>
-            (r, o,
-             apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR, NULL));
+        return upload_impl<Response>
+            (r, config,
+             file_name, file_mime, file_size, file_digest, file_temp_path,
+             remove_pass, download_pass, comment);
     } catch(const char *message) {
         if (file_temp_path != NULL) {
             apr_file_remove(file_temp_path, r->pool);
         }
-        return error_with_log<Response>(r, o, config, message);
+        return error_with_log<Response>(r, config, message);
+    }
+}
+
+template<class Response>
+static int mail_upload(typename Response::Handle *r, UploaderConfig *config,
+                       const char *arg)
+{
+    int status;
+
+    const char *file_name;
+    const char *file_mime;
+    apr_off_t file_size;
+    const char *file_digest;
+    const char *file_temp_path;
+    const char *remove_pass;
+    const char *download_pass;
+    const char *comment;
+
+    RequestReader::progress_t progress;
+    apr_array_header_t *content_array;
+
+    if (!Response::is_post_method(r)) {
+        return HTTP_BAD_REQUEST;
+    }
+
+    if ((status = Response::prepare_post_read(r)) != OK) {
+        return status;
+    }
+
+    typename Response::Reader i(&progress, r);
+
+    RFC2822Parser<typename Response::Reader> parser
+        (r->pool, i, config->temp_dir_path,
+         ITM_MAX_COMMENT_SIZE, config->file_size_limit,
+         PST_MAX_ITEM_COUNT);
+
+    content_array = parser.parse();
+
+    file_temp_path = NULL;
+    try {
+        get_mail_upload_param<typename Response::Reader>
+            (r->pool, content_array,
+             &file_name, &file_mime, &file_size, &file_digest, &file_temp_path,
+             &remove_pass, &download_pass, &comment);
+
+        return upload_impl<Response>
+            (r, config,
+             file_name, file_mime, file_size, file_digest, file_temp_path,
+             remove_pass, download_pass, comment);
+    } catch(const char *message) {
+        if (file_temp_path != NULL) {
+            apr_file_remove(file_temp_path, r->pool);
+        }
+        return error_with_log<Response>(r, config, message);
     }
-    o.finish();
 
     return OK;
 }
@@ -581,8 +666,9 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
         uitem = config->get_item_manager()->get_item(r->pool, item_id);
 
         if (!is_admin_mode) {
-            if (strncmp(remove_pass, uitem->get_remove_pass(),
-                        strlen(uitem->get_remove_pass())) != 0) {
+            if ((strlen(uitem->get_remove_pass()) == 0) ||
+                (strncmp(remove_pass, uitem->get_remove_pass(),
+                         strlen(uitem->get_remove_pass())) != 0)) {
                 THROW(MESSAGE_REMOVE_PASS_MISMATCH);
             }
         }
@@ -595,6 +681,10 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
                  apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
                              ADMIN_COMMAND, ARG_SEPARATE_STR, NULL));
         } else {
+            Response::set_env(r, "uploader_remove", "");
+            Response::set_env(r, "uploader_item_id",
+                              apr_itoa(r->pool, item_id));
+
             return redirect<Response>
                 (r, o,
                  apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
@@ -785,6 +875,8 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
         return remove<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, RSS_COMMAND)) {
         return rss<Response>(r, config, arg);
+    } else if (IS_REQUEST_COMMAND(command, MAIL_COMMAND)) {
+        return mail_upload<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, ADMIN_COMMAND)) {
         return admin<Response>(r, config, arg);
 #ifdef DEBUG
