@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: uploader_util.cpp 2170 2006-12-04 17:23:49Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,7 +38,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: uploader_util.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_util.cpp 2170 2006-12-04 17:23:49Z svn $");
 
 const char *get_word(apr_pool_t *pool, const char **input,
                      const char delimiter)
@@ -65,6 +65,14 @@ const char *get_word(apr_pool_t *pool, const char **input,
     }
 }
 
+void get_page_count(apr_size_t item_count, apr_size_t per_page_item_number,
+                    apr_size_t *page_count)
+{
+    *page_count = (item_count == 0)
+        ? 1
+        : (item_count-1)/per_page_item_number + 1;
+}
+
 void get_page(apr_pool_t *pool, const char *arg, apr_size_t page_count,
               apr_size_t *page_no)
 {
@@ -99,22 +107,22 @@ const char *get_dispos_encoding(const char *user_agent)
     return encoding;
 }
 
-bool can_post(UploaderConfig *config, const char *url)
+bool can_post(UploaderConfig *config, const char *ip_address)
 {
     if (config->is_debug_mode) {
         return true;
     }
 
-    return config->get_flow_controller()->can_post(url);
+    return config->get_flow_controller()->can_post(ip_address);
 }
 
-void regist_post(UploaderConfig *config, const char *url)
+void regist_post(UploaderConfig *config, const char *ip_address)
 {
     if (config->is_debug_mode) {
         return;
     }
 
-    config->get_flow_controller()->regist_post(url);
+    config->get_flow_controller()->regist_post(ip_address);
 }
 
 // Local Variables:
