@@ -28,8 +28,8 @@
         private void InitializeComponent()
         {
             this.components = new System.ComponentModel.Container();
-            System.Windows.Forms.ToolStripButton apacheStripButton;
             System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(UploaderConfigDialog));
+            this.thumbDirPathLabel = new System.Windows.Forms.Label();
             this.adminTmplPathLabel = new System.Windows.Forms.Label();
             this.perPageItemNumberLabel = new System.Windows.Forms.Label();
             this.totalFileNumberLimitLabel = new System.Windows.Forms.Label();
@@ -39,12 +39,9 @@
             this.pathLabel = new System.Windows.Forms.Label();
             this.modulePathLabel = new System.Windows.Forms.Label();
             this.baseUrlLabel = new System.Windows.Forms.Label();
-            this.stylesheetDirPathLabel = new System.Windows.Forms.Label();
-            this.javascriptDirPathLabel = new System.Windows.Forms.Label();
             this.tempDirPathTextBox = new System.Windows.Forms.TextBox();
             this.uploaderConfigBindingSource = new System.Windows.Forms.BindingSource(this.components);
             this.dataDirPathLabel = new System.Windows.Forms.Label();
-            this.imageDirPathLabel = new System.Windows.Forms.Label();
             this.fileDirPathLabel = new System.Windows.Forms.Label();
             this.tempDirPathLabel = new System.Windows.Forms.Label();
             this.indexTmplPathLabel = new System.Windows.Forms.Label();
@@ -66,17 +63,23 @@
             this.pathTextBox = new System.Windows.Forms.TextBox();
             this.baseUrlTextBox = new System.Windows.Forms.TextBox();
             this.tabPage2 = new System.Windows.Forms.TabPage();
-            this.javascriptDirPathButton = new System.Windows.Forms.Button();
-            this.stylesheetDirPathButton = new System.Windows.Forms.Button();
-            this.imageDirPathButton = new System.Windows.Forms.Button();
-            this.javascriptDirPathTextBox = new System.Windows.Forms.TextBox();
-            this.stylesheetDirPathTextBox = new System.Windows.Forms.TextBox();
-            this.imageDirPathTextBox = new System.Windows.Forms.TextBox();
+            this.thumbDirPathButton = new System.Windows.Forms.Button();
+            this.thumbDirPathTextBox = new System.Windows.Forms.TextBox();
             this.tempDirPathButton = new System.Windows.Forms.Button();
             this.fileDirPathButton = new System.Windows.Forms.Button();
             this.dataDirPathButton = new System.Windows.Forms.Button();
             this.dataDirPathTextBox = new System.Windows.Forms.TextBox();
             this.fileDirPathTextBox = new System.Windows.Forms.TextBox();
+            this.tabPage5 = new System.Windows.Forms.TabPage();
+            this.javascriptDirPathButton = new System.Windows.Forms.Button();
+            this.stylesheetDirPathButton = new System.Windows.Forms.Button();
+            this.imageDirPathButton = new System.Windows.Forms.Button();
+            this.javascriptDirPathLabel = new System.Windows.Forms.Label();
+            this.javascriptDirPathTextBox = new System.Windows.Forms.TextBox();
+            this.stylesheetDirPathLabel = new System.Windows.Forms.Label();
+            this.stylesheetDirPathTextBox = new System.Windows.Forms.TextBox();
+            this.imageDirPathLabel = new System.Windows.Forms.Label();
+            this.imageDirPathTextBox = new System.Windows.Forms.TextBox();
             this.tabPage4 = new System.Windows.Forms.TabPage();
             this.totalFileSizeLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
             this.totalFileNumberLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
@@ -85,7 +88,6 @@
             this.tabPage3 = new System.Windows.Forms.TabPage();
             this.adminTmplPathButton = new System.Windows.Forms.Button();
             this.adminTmplPathTextBox = new System.Windows.Forms.TextBox();
-
             this.downloadTmplPathButton = new System.Windows.Forms.Button();
             this.progressTmplPathButton = new System.Windows.Forms.Button();
             this.indexTmplPathButton = new System.Windows.Forms.Button();
@@ -98,38 +100,36 @@
             this.apache_config_textTextBox = new System.Windows.Forms.TextBox();
             this.menuToolStrip = new System.Windows.Forms.ToolStrip();
             this.copyToolStripButton = new System.Windows.Forms.ToolStripButton();
+            this.apacheStripButton = new System.Windows.Forms.ToolStripButton();
             this.toolStripSeparator1 = new System.Windows.Forms.ToolStripSeparator();
             this.helpStripButton = new System.Windows.Forms.ToolStripButton();
             this.copyButton = new System.Windows.Forms.Button();
-            apacheStripButton = new System.Windows.Forms.ToolStripButton();
             ((System.ComponentModel.ISupportInitialize)(this.uploaderConfigBindingSource)).BeginInit();
             this.configTabControl.SuspendLayout();
             this.tabPage1.SuspendLayout();
             this.groupBox2.SuspendLayout();
             this.groupBox3.SuspendLayout();
             this.tabPage2.SuspendLayout();
+            this.tabPage5.SuspendLayout();
             this.tabPage4.SuspendLayout();
             ((System.ComponentModel.ISupportInitialize)(this.totalFileSizeLimitNumericUpDown)).BeginInit();
             ((System.ComponentModel.ISupportInitialize)(this.totalFileNumberLimitNumericUpDown)).BeginInit();
             ((System.ComponentModel.ISupportInitialize)(this.perPageItemNumberNumericUpDown)).BeginInit();
             ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).BeginInit();
             this.tabPage3.SuspendLayout();
-
             ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).BeginInit();
             this.groupBox1.SuspendLayout();
             this.menuToolStrip.SuspendLayout();
             this.SuspendLayout();
             // 
-            // apacheStripButton
+            // thumbDirPathLabel
             // 
-            apacheStripButton.DisplayStyle = System.Windows.Forms.ToolStripItemDisplayStyle.Image;
-            apacheStripButton.Image = ((System.Drawing.Image)(resources.GetObject("apacheStripButton.Image")));
-            apacheStripButton.ImageTransparentColor = System.Drawing.Color.Magenta;
-            apacheStripButton.Name = "apacheStripButton";
-            apacheStripButton.Size = new System.Drawing.Size(23, 22);
-            apacheStripButton.Text = "toolStripButton1";
-            apacheStripButton.ToolTipText = "Apache フォルダを開く";
-            apacheStripButton.Click += new System.EventHandler(this.apacheStripButton_Click);
+            this.thumbDirPathLabel.AutoSize = true;
+            this.thumbDirPathLabel.Location = new System.Drawing.Point(8, 88);
+            this.thumbDirPathLabel.Name = "thumbDirPathLabel";
+            this.thumbDirPathLabel.Size = new System.Drawing.Size(141, 12);
+            this.thumbDirPathLabel.TabIndex = 9;
+            this.thumbDirPathLabel.Text = "サムネイルを保存するフォルダ";
             // 
             // adminTmplPathLabel
             // 
@@ -214,28 +214,10 @@
             this.baseUrlLabel.Text = "アップローダの URL";
             this.baseUrlLabel.Validating += new System.ComponentModel.CancelEventHandler(this.baseUrlLabel_Validating);
             // 
-            // stylesheetDirPathLabel
-            // 
-            this.stylesheetDirPathLabel.AutoSize = true;
-            this.stylesheetDirPathLabel.Location = new System.Drawing.Point(8, 168);
-            this.stylesheetDirPathLabel.Name = "stylesheetDirPathLabel";
-            this.stylesheetDirPathLabel.Size = new System.Drawing.Size(104, 12);
-            this.stylesheetDirPathLabel.TabIndex = 12;
-            this.stylesheetDirPathLabel.Text = "スタイルシートフォルダ";
-            // 
-            // javascriptDirPathLabel
-            // 
-            this.javascriptDirPathLabel.AutoSize = true;
-            this.javascriptDirPathLabel.Location = new System.Drawing.Point(8, 208);
-            this.javascriptDirPathLabel.Name = "javascriptDirPathLabel";
-            this.javascriptDirPathLabel.Size = new System.Drawing.Size(81, 12);
-            this.javascriptDirPathLabel.TabIndex = 15;
-            this.javascriptDirPathLabel.Text = "スクリプトフォルダ";
-            // 
             // tempDirPathTextBox
             // 
             this.tempDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "tempDirPath", true));
-            this.tempDirPathTextBox.Location = new System.Drawing.Point(8, 104);
+            this.tempDirPathTextBox.Location = new System.Drawing.Point(8, 144);
             this.tempDirPathTextBox.Name = "tempDirPathTextBox";
             this.tempDirPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.tempDirPathTextBox.TabIndex = 7;
@@ -250,28 +232,19 @@
             this.dataDirPathLabel.TabIndex = 0;
             this.dataDirPathLabel.Text = "データを保存するフォルダ";
             // 
-            // imageDirPathLabel
-            // 
-            this.imageDirPathLabel.AutoSize = true;
-            this.imageDirPathLabel.Location = new System.Drawing.Point(8, 128);
-            this.imageDirPathLabel.Name = "imageDirPathLabel";
-            this.imageDirPathLabel.Size = new System.Drawing.Size(64, 12);
-            this.imageDirPathLabel.TabIndex = 9;
-            this.imageDirPathLabel.Text = "画像フォルダ";
-            // 
             // fileDirPathLabel
             // 
             this.fileDirPathLabel.AutoSize = true;
             this.fileDirPathLabel.Location = new System.Drawing.Point(8, 48);
             this.fileDirPathLabel.Name = "fileDirPathLabel";
-            this.fileDirPathLabel.Size = new System.Drawing.Size(150, 12);
+            this.fileDirPathLabel.Size = new System.Drawing.Size(126, 12);
             this.fileDirPathLabel.TabIndex = 3;
-            this.fileDirPathLabel.Text = "添付ファイルを保存するフォルダ";
+            this.fileDirPathLabel.Text = "ファイルを保存するフォルダ";
             // 
             // tempDirPathLabel
             // 
             this.tempDirPathLabel.AutoSize = true;
-            this.tempDirPathLabel.Location = new System.Drawing.Point(8, 88);
+            this.tempDirPathLabel.Location = new System.Drawing.Point(8, 128);
             this.tempDirPathLabel.Name = "tempDirPathLabel";
             this.tempDirPathLabel.Size = new System.Drawing.Size(150, 12);
             this.tempDirPathLabel.TabIndex = 6;
@@ -317,6 +290,7 @@
             // 
             this.configTabControl.Controls.Add(this.tabPage1);
             this.configTabControl.Controls.Add(this.tabPage2);
+            this.configTabControl.Controls.Add(this.tabPage5);
             this.configTabControl.Controls.Add(this.tabPage4);
             this.configTabControl.Controls.Add(this.tabPage3);
             this.configTabControl.Location = new System.Drawing.Point(0, 32);
@@ -468,15 +442,10 @@
             // 
             // tabPage2
             // 
-            this.tabPage2.Controls.Add(this.javascriptDirPathButton);
-            this.tabPage2.Controls.Add(this.stylesheetDirPathButton);
-            this.tabPage2.Controls.Add(this.imageDirPathButton);
-            this.tabPage2.Controls.Add(this.javascriptDirPathLabel);
-            this.tabPage2.Controls.Add(this.javascriptDirPathTextBox);
-            this.tabPage2.Controls.Add(this.stylesheetDirPathLabel);
-            this.tabPage2.Controls.Add(this.stylesheetDirPathTextBox);
-            this.tabPage2.Controls.Add(this.imageDirPathLabel);
-            this.tabPage2.Controls.Add(this.imageDirPathTextBox);
+            this.tabPage2.AutoScroll = true;
+            this.tabPage2.Controls.Add(this.thumbDirPathButton);
+            this.tabPage2.Controls.Add(this.thumbDirPathLabel);
+            this.tabPage2.Controls.Add(this.thumbDirPathTextBox);
             this.tabPage2.Controls.Add(this.tempDirPathButton);
             this.tabPage2.Controls.Add(this.fileDirPathButton);
             this.tabPage2.Controls.Add(this.dataDirPathButton);
@@ -491,69 +460,31 @@
             this.tabPage2.Padding = new System.Windows.Forms.Padding(3);
             this.tabPage2.Size = new System.Drawing.Size(448, 263);
             this.tabPage2.TabIndex = 1;
-            this.tabPage2.Text = "フォルダ";
+            this.tabPage2.Text = "フォルダ(1)";
             this.tabPage2.UseVisualStyleBackColor = true;
             // 
-            // javascriptDirPathButton
+            // thumbDirPathButton
             // 
-            this.javascriptDirPathButton.Location = new System.Drawing.Point(384, 224);
-            this.javascriptDirPathButton.Name = "javascriptDirPathButton";
-            this.javascriptDirPathButton.Size = new System.Drawing.Size(56, 23);
-            this.javascriptDirPathButton.TabIndex = 17;
-            this.javascriptDirPathButton.Text = "参照";
-            this.javascriptDirPathButton.UseVisualStyleBackColor = true;
-            this.javascriptDirPathButton.Click += new System.EventHandler(this.javascriptDirPathButton_Click);
+            this.thumbDirPathButton.Location = new System.Drawing.Point(384, 104);
+            this.thumbDirPathButton.Name = "thumbDirPathButton";
+            this.thumbDirPathButton.Size = new System.Drawing.Size(56, 23);
+            this.thumbDirPathButton.TabIndex = 11;
+            this.thumbDirPathButton.Text = "参照";
+            this.thumbDirPathButton.UseVisualStyleBackColor = true;
+            this.thumbDirPathButton.Click += new System.EventHandler(this.thumbDirPathButton_Click);
             // 
-            // stylesheetDirPathButton
+            // thumbDirPathTextBox
             // 
-            this.stylesheetDirPathButton.Location = new System.Drawing.Point(384, 184);
-            this.stylesheetDirPathButton.Name = "stylesheetDirPathButton";
-            this.stylesheetDirPathButton.Size = new System.Drawing.Size(56, 23);
-            this.stylesheetDirPathButton.TabIndex = 14;
-            this.stylesheetDirPathButton.Text = "参照";
-            this.stylesheetDirPathButton.UseVisualStyleBackColor = true;
-            this.stylesheetDirPathButton.Click += new System.EventHandler(this.stylesheetDirPathButton_Click);
-            // 
-            // imageDirPathButton
-            // 
-            this.imageDirPathButton.Location = new System.Drawing.Point(384, 144);
-            this.imageDirPathButton.Name = "imageDirPathButton";
-            this.imageDirPathButton.Size = new System.Drawing.Size(56, 23);
-            this.imageDirPathButton.TabIndex = 11;
-            this.imageDirPathButton.Text = "参照";
-            this.imageDirPathButton.UseVisualStyleBackColor = true;
-            this.imageDirPathButton.Click += new System.EventHandler(this.imageDirPathButton_Click);
-            // 
-            // javascriptDirPathTextBox
-            // 
-            this.javascriptDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "javascriptDirPath", true));
-            this.javascriptDirPathTextBox.Location = new System.Drawing.Point(8, 224);
-            this.javascriptDirPathTextBox.Name = "javascriptDirPathTextBox";
-            this.javascriptDirPathTextBox.Size = new System.Drawing.Size(360, 19);
-            this.javascriptDirPathTextBox.TabIndex = 16;
-            this.javascriptDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
-            // 
-            // stylesheetDirPathTextBox
-            // 
-            this.stylesheetDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "stylesheetDirPath", true));
-            this.stylesheetDirPathTextBox.Location = new System.Drawing.Point(8, 184);
-            this.stylesheetDirPathTextBox.Name = "stylesheetDirPathTextBox";
-            this.stylesheetDirPathTextBox.Size = new System.Drawing.Size(360, 19);
-            this.stylesheetDirPathTextBox.TabIndex = 13;
-            this.stylesheetDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
-            // 
-            // imageDirPathTextBox
-            // 
-            this.imageDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "imageDirPath", true));
-            this.imageDirPathTextBox.Location = new System.Drawing.Point(8, 144);
-            this.imageDirPathTextBox.Name = "imageDirPathTextBox";
-            this.imageDirPathTextBox.Size = new System.Drawing.Size(360, 19);
-            this.imageDirPathTextBox.TabIndex = 10;
-            this.imageDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
+            this.thumbDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "thumbDirPath", true));
+            this.thumbDirPathTextBox.Location = new System.Drawing.Point(8, 104);
+            this.thumbDirPathTextBox.Name = "thumbDirPathTextBox";
+            this.thumbDirPathTextBox.Size = new System.Drawing.Size(360, 19);
+            this.thumbDirPathTextBox.TabIndex = 10;
+            this.thumbDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             // 
             // tempDirPathButton
             // 
-            this.tempDirPathButton.Location = new System.Drawing.Point(384, 104);
+            this.tempDirPathButton.Location = new System.Drawing.Point(384, 144);
             this.tempDirPathButton.Name = "tempDirPathButton";
             this.tempDirPathButton.Size = new System.Drawing.Size(56, 23);
             this.tempDirPathButton.TabIndex = 8;
@@ -599,6 +530,102 @@
             this.fileDirPathTextBox.TabIndex = 4;
             this.fileDirPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             // 
+            // tabPage5
+            // 
+            this.tabPage5.Controls.Add(this.javascriptDirPathButton);
+            this.tabPage5.Controls.Add(this.stylesheetDirPathButton);
+            this.tabPage5.Controls.Add(this.imageDirPathButton);
+            this.tabPage5.Controls.Add(this.javascriptDirPathLabel);
+            this.tabPage5.Controls.Add(this.javascriptDirPathTextBox);
+            this.tabPage5.Controls.Add(this.stylesheetDirPathLabel);
+            this.tabPage5.Controls.Add(this.stylesheetDirPathTextBox);
+            this.tabPage5.Controls.Add(this.imageDirPathLabel);
+            this.tabPage5.Controls.Add(this.imageDirPathTextBox);
+            this.tabPage5.Location = new System.Drawing.Point(4, 21);
+            this.tabPage5.Name = "tabPage5";
+            this.tabPage5.Size = new System.Drawing.Size(448, 263);
+            this.tabPage5.TabIndex = 4;
+            this.tabPage5.Text = "フォルダ(2)";
+            this.tabPage5.UseVisualStyleBackColor = true;
+            // 
+            // javascriptDirPathButton
+            // 
+            this.javascriptDirPathButton.Location = new System.Drawing.Point(384, 104);
+            this.javascriptDirPathButton.Name = "javascriptDirPathButton";
+            this.javascriptDirPathButton.Size = new System.Drawing.Size(56, 23);
+            this.javascriptDirPathButton.TabIndex = 26;
+            this.javascriptDirPathButton.Text = "参照";
+            this.javascriptDirPathButton.UseVisualStyleBackColor = true;
+            // 
+            // stylesheetDirPathButton
+            // 
+            this.stylesheetDirPathButton.Location = new System.Drawing.Point(384, 64);
+            this.stylesheetDirPathButton.Name = "stylesheetDirPathButton";
+            this.stylesheetDirPathButton.Size = new System.Drawing.Size(56, 23);
+            this.stylesheetDirPathButton.TabIndex = 23;
+            this.stylesheetDirPathButton.Text = "参照";
+            this.stylesheetDirPathButton.UseVisualStyleBackColor = true;
+            // 
+            // imageDirPathButton
+            // 
+            this.imageDirPathButton.Location = new System.Drawing.Point(384, 24);
+            this.imageDirPathButton.Name = "imageDirPathButton";
+            this.imageDirPathButton.Size = new System.Drawing.Size(56, 23);
+            this.imageDirPathButton.TabIndex = 20;
+            this.imageDirPathButton.Text = "参照";
+            this.imageDirPathButton.UseVisualStyleBackColor = true;
+            // 
+            // javascriptDirPathLabel
+            // 
+            this.javascriptDirPathLabel.AutoSize = true;
+            this.javascriptDirPathLabel.Location = new System.Drawing.Point(8, 88);
+            this.javascriptDirPathLabel.Name = "javascriptDirPathLabel";
+            this.javascriptDirPathLabel.Size = new System.Drawing.Size(81, 12);
+            this.javascriptDirPathLabel.TabIndex = 24;
+            this.javascriptDirPathLabel.Text = "スクリプトフォルダ";
+            // 
+            // javascriptDirPathTextBox
+            // 
+            this.javascriptDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "javascriptDirPath", true));
+            this.javascriptDirPathTextBox.Location = new System.Drawing.Point(8, 104);
+            this.javascriptDirPathTextBox.Name = "javascriptDirPathTextBox";
+            this.javascriptDirPathTextBox.Size = new System.Drawing.Size(360, 19);
+            this.javascriptDirPathTextBox.TabIndex = 25;
+            // 
+            // stylesheetDirPathLabel
+            // 
+            this.stylesheetDirPathLabel.AutoSize = true;
+            this.stylesheetDirPathLabel.Location = new System.Drawing.Point(8, 48);
+            this.stylesheetDirPathLabel.Name = "stylesheetDirPathLabel";
+            this.stylesheetDirPathLabel.Size = new System.Drawing.Size(104, 12);
+            this.stylesheetDirPathLabel.TabIndex = 21;
+            this.stylesheetDirPathLabel.Text = "スタイルシートフォルダ";
+            // 
+            // stylesheetDirPathTextBox
+            // 
+            this.stylesheetDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "stylesheetDirPath", true));
+            this.stylesheetDirPathTextBox.Location = new System.Drawing.Point(8, 64);
+            this.stylesheetDirPathTextBox.Name = "stylesheetDirPathTextBox";
+            this.stylesheetDirPathTextBox.Size = new System.Drawing.Size(360, 19);
+            this.stylesheetDirPathTextBox.TabIndex = 22;
+            // 
+            // imageDirPathLabel
+            // 
+            this.imageDirPathLabel.AutoSize = true;
+            this.imageDirPathLabel.Location = new System.Drawing.Point(8, 8);
+            this.imageDirPathLabel.Name = "imageDirPathLabel";
+            this.imageDirPathLabel.Size = new System.Drawing.Size(64, 12);
+            this.imageDirPathLabel.TabIndex = 18;
+            this.imageDirPathLabel.Text = "画像フォルダ";
+            // 
+            // imageDirPathTextBox
+            // 
+            this.imageDirPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "imageDirPath", true));
+            this.imageDirPathTextBox.Location = new System.Drawing.Point(8, 24);
+            this.imageDirPathTextBox.Name = "imageDirPathTextBox";
+            this.imageDirPathTextBox.Size = new System.Drawing.Size(360, 19);
+            this.imageDirPathTextBox.TabIndex = 19;
+            // 
             // tabPage4
             // 
             this.tabPage4.Controls.Add(this.totalFileSizeLimitLabel);
@@ -726,9 +753,6 @@
             this.adminTmplPathTextBox.TabIndex = 13;
             this.adminTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             // 
-            // uploaderConfigBindingSource1
-            // 
-            // 
             // downloadTmplPathButton
             // 
             this.downloadTmplPathButton.Location = new System.Drawing.Point(384, 104);
@@ -827,7 +851,7 @@
             // 
             this.menuToolStrip.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
             this.copyToolStripButton,
-            apacheStripButton,
+            this.apacheStripButton,
             this.toolStripSeparator1,
             this.helpStripButton});
             this.menuToolStrip.Location = new System.Drawing.Point(0, 0);
@@ -835,6 +859,7 @@
             this.menuToolStrip.Size = new System.Drawing.Size(457, 25);
             this.menuToolStrip.TabIndex = 0;
             this.menuToolStrip.Text = "toolStrip1";
+            this.menuToolStrip.ItemClicked += new System.Windows.Forms.ToolStripItemClickedEventHandler(this.menuToolStrip_ItemClicked);
             // 
             // copyToolStripButton
             // 
@@ -846,6 +871,17 @@
             this.copyToolStripButton.Text = "設定をコピー";
             this.copyToolStripButton.Click += new System.EventHandler(this.copyToolStripButton_Click);
             // 
+            // apacheStripButton
+            // 
+            this.apacheStripButton.DisplayStyle = System.Windows.Forms.ToolStripItemDisplayStyle.Image;
+            this.apacheStripButton.Image = ((System.Drawing.Image)(resources.GetObject("apacheStripButton.Image")));
+            this.apacheStripButton.ImageTransparentColor = System.Drawing.Color.Magenta;
+            this.apacheStripButton.Name = "apacheStripButton";
+            this.apacheStripButton.Size = new System.Drawing.Size(23, 22);
+            this.apacheStripButton.Text = "Apache フォルダを開く";
+            this.apacheStripButton.ToolTipText = "Apache フォルダを開く";
+            this.apacheStripButton.Click += new System.EventHandler(this.apacheStripButton_Click);
+            // 
             // toolStripSeparator1
             // 
             this.toolStripSeparator1.Name = "toolStripSeparator1";
@@ -883,7 +919,6 @@
             this.Controls.Add(this.groupBox1);
             this.Controls.Add(this.configTabControl);
             this.DoubleBuffered = true;
-            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
             this.MaximizeBox = false;
             this.Name = "UploaderConfigDialog";
             this.Text = "mod_uploader 設定情報生成ツール";
@@ -898,6 +933,8 @@
             this.groupBox3.PerformLayout();
             this.tabPage2.ResumeLayout(false);
             this.tabPage2.PerformLayout();
+            this.tabPage5.ResumeLayout(false);
+            this.tabPage5.PerformLayout();
             this.tabPage4.ResumeLayout(false);
             this.tabPage4.PerformLayout();
             ((System.ComponentModel.ISupportInitialize)(this.totalFileSizeLimitNumericUpDown)).EndInit();
@@ -946,16 +983,7 @@
         private System.Windows.Forms.Button dataDirPathButton;
         private System.Windows.Forms.ToolStrip menuToolStrip;
         private System.Windows.Forms.ToolStripButton copyToolStripButton;
-        private System.Windows.Forms.TextBox javascriptDirPathTextBox;
-        private System.Windows.Forms.TextBox stylesheetDirPathTextBox;
-        private System.Windows.Forms.TextBox imageDirPathTextBox;
-        private System.Windows.Forms.Button javascriptDirPathButton;
-        private System.Windows.Forms.Button stylesheetDirPathButton;
-        private System.Windows.Forms.Button imageDirPathButton;
         private System.Windows.Forms.Label dataDirPathLabel;
-        private System.Windows.Forms.Label imageDirPathLabel;
-        private System.Windows.Forms.Label stylesheetDirPathLabel;
-        private System.Windows.Forms.Label javascriptDirPathLabel;
         private System.Windows.Forms.TextBox tempDirPathTextBox;
         private System.Windows.Forms.Label imagemagickPathLabel;
         private System.Windows.Forms.Label apachePathLabel;
@@ -989,5 +1017,19 @@
         private System.Windows.Forms.TextBox adminTmplPathTextBox;
 
         private System.Windows.Forms.Label adminTmplPathLabel;
+        private System.Windows.Forms.Button thumbDirPathButton;
+        private System.Windows.Forms.TextBox thumbDirPathTextBox;
+        private System.Windows.Forms.TabPage tabPage5;
+        private System.Windows.Forms.Button javascriptDirPathButton;
+        private System.Windows.Forms.Button stylesheetDirPathButton;
+        private System.Windows.Forms.Button imageDirPathButton;
+        private System.Windows.Forms.Label javascriptDirPathLabel;
+        private System.Windows.Forms.TextBox javascriptDirPathTextBox;
+        private System.Windows.Forms.Label stylesheetDirPathLabel;
+        private System.Windows.Forms.TextBox stylesheetDirPathTextBox;
+        private System.Windows.Forms.Label imageDirPathLabel;
+        private System.Windows.Forms.TextBox imageDirPathTextBox;
+        private System.Windows.Forms.Label thumbDirPathLabel;
+        private System.Windows.Forms.ToolStripButton apacheStripButton;
     }
 }
\ No newline at end of file
