@@ -72,6 +72,8 @@ namespace UploaderConfig
                 new CancelEventHandler((new FolderPathValidator(dataDirPathLabel, errorProvider)).validate);
             fileDirPathTextBox.Validating += 
                 new CancelEventHandler((new FolderPathValidator(fileDirPathLabel, errorProvider)).validate);
+            thumbDirPathTextBox.Validating += 
+                new CancelEventHandler((new FolderPathValidator(thumbDirPathLabel, errorProvider)).validate);
             tempDirPathTextBox.Validating += 
                 new CancelEventHandler((new FolderPathValidator(tempDirPathLabel, errorProvider)).validate);
 
@@ -235,6 +237,20 @@ namespace UploaderConfig
             ValidateChildren();
         }
 
+        private void thumbDirPathButton_Click(object sender, EventArgs e)
+        {
+            string folder_path = chooseFolder(thumbDirPathLabel,
+                thumbDirPathTextBox.Text);
+
+            if (folder_path == null) {
+                return;
+            }
+
+            uploaderConfig.thumbDirPath = folder_path;
+            uploaderConfigBindingSource.ResetBindings(false);
+            ValidateChildren();
+        }
+
         private void tempDirPathButton_Click(object sender, EventArgs e)
         {
             string folder_path = chooseFolder(tempDirPathLabel, 
@@ -487,5 +503,10 @@ namespace UploaderConfig
         {
             ValidateChildren();
         }
+
+        private void menuToolStrip_ItemClicked(object sender, ToolStripItemClickedEventArgs e)
+        {
+
+        }
     }
 }
